
******

Bravo!  You have received a Medical Diploma in "Skull" from   
the Orbital Convergence University International Air and Water Embassy of the Tangerine Planet.  

You are now officially certified to include "Skull" in your practice.

******

# Skull

## obtain
(ZSH) pip install Skull

## tutorial
(ZSH) Skull shares